@@ -417,6 +417,9 @@ def get_vars(namespace: str, *variable_keys: str) -> dict[str, str]:
         ValueError: If namespace is empty or any specified key is invalid.
         TypeError: If arguments have incorrect types.
         EnvchainError: If the envchain command fails (e.g., namespace not found).
+
+    Note:
+    never use --show-value outside of get_vars function!!!
     """
     if not isinstance(namespace, str) or not namespace.strip():
         raise ValueError("Namespace must be a non-empty string.")
